/*
 * Awake File: Easy file upload & download through HTTP with Java
 * Awake SQL: Remote JDBC access through HTTP.                                    
 * Copyright (C) 2011, Kawan Softwares S.A.S.
 * (http://www.awakeframework.org). All rights reserved.                                
 *                                                                               
 * Awake File/SQL is free software; you can redistribute it and/or                 
 * modify it under the terms of the GNU Lesser General Public                    
 * License as published by the Free Software Foundation; either                  
 * version 2.1 of the License, or (at your option) any later version.            
 *                                                                               
 * Awake File/SQL is distributed in the hope that it will be useful,               
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             
 * Lesser General Public License for more details.                               
 *                                                                               
 * You should have received a copy of the GNU Lesser General Public              
 * License along with this library; if not, write to the Free Software           
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
 * 02110-1301  USA
 *
 * Any modifications to this file must keep this entire header
 * intact.
 */

//AwakeSecurityException.java
//Copyright (c) Kawan Softwares S.A.S, 2011
//
//Last Updates: 
// 12 avr. 2011 16:01:14 Nicolas de Pomereu
// 17/06/11 20:55 NDP : AwakeSecurityException: does not extends anymore IOException
// 05/12/11 15:15 NDP : AwakeSecurityException: clean Javadoc

package org.awakefw.commons.api.client;

/**
 * Security Exception thrown when an illegal operation is asked by the Client side.
 * 
 * @author Nicolas de Pomereu
 * @since 1.0
 * 
 */
public class AwakeSecurityException extends Exception {

    private static final long serialVersionUID = -7290646904893713220L;

    private String remoteStackTrace = null;

    /**
     * Constructs an {@code AwakeSecurityException} with {@code null} as its
     * error detail message.
     */
    public AwakeSecurityException() {
    }

    /**
     * Constructs an {@code AwakeSecurityException} with the specified detail
     * message.
     * 
     * @param message
     *            The detail message (which is saved for later retrieval by the
     *            {@link #getMessage()} method)
     */
    public AwakeSecurityException(String message) {
	super(message);
    }

    /**
     * Constructs an {@code AwakeSecurityException} with the specified detail
     * message.
     * 
     * @param message
     *            The detail message (which is saved for later retrieval by the
     *            {@link #getMessage()} method)
     * 
     * @param remoteStackTrace
     *            the remote stack trace as string
     */
    public AwakeSecurityException(String message, String remoteStackTrace) {
	super(message);
	this.remoteStackTrace = remoteStackTrace;
    }

    /**
     * Returns the remote stack trace as a display string.
     * 
     * @return the remote Stack Trace as a display string
     */
    public String getRemoteStackTrace() {
	return this.remoteStackTrace;
    }

}
